Docker Jobber
==============================

Docker Jobber (`jobber`) is a command line interface (CLI) application for managing machine learning workflows using Docker.

> Please see the [homepage](https://github.com/mentice/docker-jobber) for documentation and examples

## Installation
You'll need [Docker](www.docker.com/get-started) of course, then install the `jobber` command using pip (Docker Jobber requires Python3):

```
pip install docker-jobber
```
